@@ -1,22 +1,20 @@
 module Main.Properties where
 
-import Main.Prelude hiding (assert, isRight, isLeft)
-import Test.QuickCheck
-import Test.QuickCheck.Instances
-import qualified Data.Scientific as Scientific
-import qualified Data.UUID as UUID
-import qualified Data.Vector as Vector
+import qualified Database.PostgreSQL.LibPQ as LibPQ
+import qualified Main.IO as IO
+import Main.Prelude hiding (isLeft, isRight)
+import qualified Main.TextEncoder as C
 import qualified PostgreSQL.Binary.Decoding as A
 import qualified PostgreSQL.Binary.Encoding as B
-import qualified Main.TextEncoder as C 
-import qualified Main.PTI as PTI
-import qualified Main.DB as DB
-import qualified Main.IO as IO
-import qualified Database.PostgreSQL.LibPQ as LibPQ
+import Test.QuickCheck
 
-
-roundtrip :: (Show a, Eq a) => 
-  LibPQ.Oid -> (Bool -> (a -> B.Encoding)) -> (Bool -> A.Value a) -> a -> Property
+roundtrip ::
+  (Show a, Eq a) =>
+  LibPQ.Oid ->
+  (Bool -> (a -> B.Encoding)) ->
+  (Bool -> A.Value a) ->
+  a ->
+  Property
 roundtrip oid encoder decoder value =
   Right value === unsafePerformIO (IO.roundtrip oid encoder decoder value)
 
